@@ -3,7 +3,8 @@
 #include <termios.h>
 #include <string.h>
 #include <glib/gprintf.h>
-#include "ggit.h"
+
+#include "libgit2-glib/ggit.h"
 
 typedef struct
 {
@@ -24,10 +25,9 @@ cloner_init (Cloner *cloner)
 {
 }
 
-static gboolean
+static void
 cloner_transfer_progress (GgitRemoteCallbacks   *callbacks,
-                          GgitTransferProgress  *stats,
-                          GError               **error)
+                          GgitTransferProgress  *stats)
 {
 	guint recvobjs;
 	guint totobjs;
@@ -51,8 +51,6 @@ cloner_transfer_progress (GgitRemoteCallbacks   *callbacks,
 	{
 		g_printf("\n");
 	}
-
-	return TRUE;
 }
 
 static void
@@ -68,23 +66,25 @@ chomp (gchar *s)
 	}
 }
 
-static gboolean
+static GgitCred *
 cloner_credentials (GgitRemoteCallbacks  *callbacks,
                     const gchar          *url,
                     const gchar          *username_from_url,
                     guint                 allowed_types,
-                    GgitCred            **cred,
                     GError              **error)
 {
 	gchar username[128];
 	gchar password[128];
 	struct termios old, new;
+	GgitCred *cred;
+
+	g_return_val_if_fail (error != NULL && *error == NULL, NULL);
 
 	g_printf ("Username: ");
 
 	if (fgets (username, sizeof (username) - 1, stdin) == NULL)
 	{
-		return FALSE;
+		return NULL;
 	}
 
 	g_printf ("Password: ");
@@ -92,7 +92,7 @@ cloner_credentials (GgitRemoteCallbacks  *callbacks,
 
 	if (tcgetattr (STDIN_FILENO, &old) != 0)
 	{
-		return FALSE;
+		return NULL;
 	}
 
 	new = old;
@@ -100,14 +100,14 @@ cloner_credentials (GgitRemoteCallbacks  *callbacks,
 
 	if (tcsetattr (STDIN_FILENO, TCSAFLUSH, &new) != 0)
 	{
-		return FALSE;
+		return NULL;
 	}
 
 	if (fgets (password, sizeof (password) - 1, stdin) == NULL)
 	{
 		tcsetattr (STDIN_FILENO, TCSAFLUSH, &old);
 
-		return FALSE;
+		return NULL;
 	}
 
 	tcsetattr (STDIN_FILENO, TCSAFLUSH, &old);
@@ -115,14 +115,19 @@ cloner_credentials (GgitRemoteCallbacks  *callbacks,
 	chomp (username);
 	chomp (password);
 
-	*cred = GGIT_CRED (ggit_cred_plaintext_new (username, password, error));
+	cred = GGIT_CRED (ggit_cred_plaintext_new (username, password, error));
 
 	if (*error != NULL)
 	{
-		return FALSE;
+		if (cred != NULL)
+		{
+			g_object_unref (cred);
+		}
+
+		return NULL;
 	}
 
-	return TRUE;
+	return cred;
 }
 
 static void
@@ -143,6 +148,7 @@ int main(int argc, char **argv)
 	GError *error = NULL;
 	GFile *location;
 	Cloner *cloner;
+	GgitFetchOptions *fetch_options;
 
 	// Validate args
 	if (argc < 3) {
@@ -158,13 +164,15 @@ int main(int argc, char **argv)
 	location = g_file_new_for_commandline_arg (path);
 
 	options = ggit_clone_options_new ();
-	cloner = g_object_new (cloner_get_type(), NULL);
-
-	ggit_clone_options_set_remote_callbacks (options,
+	cloner = g_object_new (cloner_get_type (), NULL);
+	fetch_options = ggit_fetch_options_new ();
+	ggit_fetch_options_set_remote_callbacks (fetch_options,
 	                                         GGIT_REMOTE_CALLBACKS (cloner));
-
 	g_object_unref (cloner);
 
+	ggit_clone_options_set_fetch_options (options, fetch_options);
+	ggit_fetch_options_free (fetch_options);
+
 	// Do the clone
 	cloned_repo = ggit_repository_clone (url, location, options, &error);
 
