@@ -55,6 +55,32 @@ ggit_feature_flags_get_type (void)
 	return the_type;
 }
 
+GType
+ggit_diff_binary_type_get_type (void)
+{
+	static GType the_type = 0;
+	
+	if (the_type == 0)
+	{
+		static const GEnumValue values[] = {
+			{ GGIT_DIFF_BINARY_NONE,
+			  "GGIT_DIFF_BINARY_NONE",
+			  "none" },
+			{ GGIT_DIFF_BINARY_LITERAL,
+			  "GGIT_DIFF_BINARY_LITERAL",
+			  "literal" },
+			{ GGIT_DIFF_BINARY_DELTA,
+			  "GGIT_DIFF_BINARY_DELTA",
+			  "delta" },
+			{ 0, NULL, NULL }
+		};
+		the_type = g_enum_register_static (
+				g_intern_static_string ("GgitDiffBinaryType"),
+				values);
+	}
+	return the_type;
+}
+
 GType
 ggit_blame_flags_get_type (void)
 {
@@ -495,6 +521,9 @@ ggit_remote_download_tags_type_get_type (void)
 	if (the_type == 0)
 	{
 		static const GEnumValue values[] = {
+			{ GGIT_REMOTE_DOWNLOAD_TAGS_UNSPECIFIED,
+			  "GGIT_REMOTE_DOWNLOAD_TAGS_UNSPECIFIED",
+			  "unspecified" },
 			{ GGIT_REMOTE_DOWNLOAD_TAGS_AUTO,
 			  "GGIT_REMOTE_DOWNLOAD_TAGS_AUTO",
 			  "auto" },
@@ -710,9 +739,9 @@ ggit_submodule_ignore_get_type (void)
 	if (the_type == 0)
 	{
 		static const GEnumValue values[] = {
-			{ GGIT_SUBMODULE_IGNORE_RESET,
-			  "GGIT_SUBMODULE_IGNORE_RESET",
-			  "reset" },
+			{ GGIT_SUBMODULE_IGNORE_UNSPECIFIED,
+			  "GGIT_SUBMODULE_IGNORE_UNSPECIFIED",
+			  "unspecified" },
 			{ GGIT_SUBMODULE_IGNORE_NONE,
 			  "GGIT_SUBMODULE_IGNORE_NONE",
 			  "none" },
@@ -734,6 +763,32 @@ ggit_submodule_ignore_get_type (void)
 	return the_type;
 }
 
+GType
+ggit_submodule_recurse_get_type (void)
+{
+	static GType the_type = 0;
+	
+	if (the_type == 0)
+	{
+		static const GEnumValue values[] = {
+			{ GGIT_SUBMODULE_RECURSE_NO,
+			  "GGIT_SUBMODULE_RECURSE_NO",
+			  "no" },
+			{ GGIT_SUBMODULE_RECURSE_YES,
+			  "GGIT_SUBMODULE_RECURSE_YES",
+			  "yes" },
+			{ GGIT_SUBMODULE_RECURSE_ONDEMAND,
+			  "GGIT_SUBMODULE_RECURSE_ONDEMAND",
+			  "ondemand" },
+			{ 0, NULL, NULL }
+		};
+		the_type = g_enum_register_static (
+				g_intern_static_string ("GgitSubmoduleRecurse"),
+				values);
+	}
+	return the_type;
+}
+
 GType
 ggit_submodule_status_get_type (void)
 {
@@ -801,9 +856,6 @@ ggit_submodule_update_get_type (void)
 	if (the_type == 0)
 	{
 		static const GEnumValue values[] = {
-			{ GGIT_SUBMODULE_UPDATE_RESET,
-			  "GGIT_SUBMODULE_UPDATE_RESET",
-			  "reset" },
 			{ GGIT_SUBMODULE_UPDATE_CHECKOUT,
 			  "GGIT_SUBMODULE_UPDATE_CHECKOUT",
 			  "checkout" },
@@ -816,6 +868,9 @@ ggit_submodule_update_get_type (void)
 			{ GGIT_SUBMODULE_UPDATE_NONE,
 			  "GGIT_SUBMODULE_UPDATE_NONE",
 			  "none" },
+			{ GGIT_SUBMODULE_UPDATE_DEFAULT,
+			  "GGIT_SUBMODULE_UPDATE_DEFAULT",
+			  "default" },
 			{ 0, NULL, NULL }
 		};
 		the_type = g_enum_register_static (
@@ -993,12 +1048,12 @@ ggit_checkout_strategy_get_type (void)
 			{ GGIT_CHECKOUT_SAFE,
 			  "GGIT_CHECKOUT_SAFE",
 			  "safe" },
-			{ GGIT_CHECKOUT_SAFE_CREATE,
-			  "GGIT_CHECKOUT_SAFE_CREATE",
-			  "safe-create" },
 			{ GGIT_CHECKOUT_FORCE,
 			  "GGIT_CHECKOUT_FORCE",
 			  "force" },
+			{ GGIT_CHECKOUT_RECREATE_MISSING,
+			  "GGIT_CHECKOUT_RECREATE_MISSING",
+			  "recreate-missing" },
 			{ GGIT_CHECKOUT_ALLOW_CONFLICTS,
 			  "GGIT_CHECKOUT_ALLOW_CONFLICTS",
 			  "allow-conflicts" },
@@ -1041,6 +1096,18 @@ ggit_checkout_strategy_get_type (void)
 			{ GGIT_CHECKOUT_CONFLICT_STYLE_DIFF3,
 			  "GGIT_CHECKOUT_CONFLICT_STYLE_DIFF3",
 			  "conflict-style-diff3" },
+			{ GGIT_CHECKOUT_DONT_REMOVE_EXISTING,
+			  "GGIT_CHECKOUT_DONT_REMOVE_EXISTING",
+			  "dont-remove-existing" },
+			{ GGIT_CHECKOUT_DONT_WRITE_INDEX,
+			  "GGIT_CHECKOUT_DONT_WRITE_INDEX",
+			  "dont-write-index" },
+			{ GGIT_CHECKOUT_UPDATE_SUBMODULES,
+			  "GGIT_CHECKOUT_UPDATE_SUBMODULES",
+			  "update-submodules" },
+			{ GGIT_CHECKOUT_UPDATE_SUBMODULES_IF_CHANGED,
+			  "GGIT_CHECKOUT_UPDATE_SUBMODULES_IF_CHANGED",
+			  "update-submodules-if-changed" },
 			{ 0, NULL, NULL }
 		};
 		the_type = g_flags_register_static (
