@@ -25,27 +25,6 @@
 
 G_BEGIN_DECLS
 
-/**
- * GgitBlob:
- *
- * Represents a blob object.
- */
-typedef struct _GgitBlob GgitBlob;
-
-/**
- * GgitBlobOutputStream:
- *
- * Represents a blob stream object.
- */
-typedef struct _GgitBlobOutputStream GgitBlobOutputStream;
-
-/**
- * GgitBranch:
- *
- * Represents a branch object.
- */
-typedef struct _GgitBranch GgitBranch;
-
 /**
  * GgitBranchEnumerator:
  *
@@ -60,27 +39,6 @@ typedef struct _GgitBranchEnumerator GgitBranchEnumerator;
  */
 typedef struct _GgitCloneOptions GgitCloneOptions;
 
-/**
- * GgitCommit:
- *
- * Represents a commit object.
- */
-typedef struct _GgitCommit GgitCommit;
-
-/**
- * GgitCommitParents:
- *
- * Represents the parents of a commit object.
- */
-typedef struct _GgitCommitParents GgitCommitParents;
-
-/**
- * GgitConfig:
- *
- * Represents a git configuration.
- */
-typedef struct _GgitConfig GgitConfig;
-
 /**
  * GgitConfigEntry:
  *
@@ -88,20 +46,6 @@ typedef struct _GgitConfig GgitConfig;
  */
 typedef struct _GgitConfigEntry GgitConfigEntry;
 
-/**
- * GgitCred:
- *
- * Represents a git credential.
- */
-typedef struct _GgitCred GgitCred;
-
-/**
- * GgitCredSshInteractive:
- *
- * Represents a ssh interactive credential.
- */
-typedef struct _GgitCredSshInteractive GgitCredSshInteractive;
-
 /**
  * GgitCredSshInteractivePrompt:
  *
@@ -110,25 +54,18 @@ typedef struct _GgitCredSshInteractive GgitCredSshInteractive;
 typedef struct _GgitCredSshInteractivePrompt GgitCredSshInteractivePrompt;
 
 /**
- * GgitCredSshKeyFromAgent:
+ * GgitDiffBinary:
  *
- * Represents a ssh key agent credential.
+ * Represents a diff binary.
  */
-typedef struct _GgitCredSshKeyFromAgent GgitCredSshKeyFromAgent;
+typedef struct _GgitDiffBinary GgitDiffBinary;
 
 /**
- * GgitCredPlaintext:
+ * GgitDiffBinaryFile:
  *
- * Represents a plain text credential.
+ * Represents a diff binary file.
  */
-typedef struct _GgitCredPlaintext GgitCredPlaintext;
-
-/**
- * GgitDiff:
- *
- * Represents a diff list.
- */
-typedef struct _GgitDiff GgitDiff;
+typedef struct _GgitDiffBinaryFile GgitDiffBinaryFile;
 
 /**
  * GgitDiffDelta:
@@ -144,13 +81,6 @@ typedef struct _GgitDiffDelta GgitDiffDelta;
  */
 typedef struct _GgitDiffFile GgitDiffFile;
 
-/**
- * GgitDiffFindOptions:
- *
- * Represents options for finding diff similarity.
- */
-typedef struct _GgitDiffFindOptions GgitDiffFindOptions;
-
 /**
  * GgitDiffHunk:
  *
@@ -165,13 +95,6 @@ typedef struct _GgitDiffHunk GgitDiffHunk;
  */
 typedef struct _GgitDiffLine GgitDiffLine;
 
-/**
- * GgitDiffOptions:
- *
- * Represents the options used when creating a #GgitDiff.
- */
-typedef struct _GgitDiffOptions GgitDiffOptions;
-
 /**
  * GgitDiffSimilarityMetric:
  *
@@ -179,13 +102,6 @@ typedef struct _GgitDiffOptions GgitDiffOptions;
  */
 typedef struct _GgitDiffSimilarityMetric GgitDiffSimilarityMetric;
 
-/**
- * GgitBlame:
- *
- * Represents a blame.
- */
-typedef struct _GgitBlame GgitBlame;
-
 /**
  * GgitBlameHunk:
  *
@@ -194,11 +110,11 @@ typedef struct _GgitBlame GgitBlame;
 typedef struct _GgitBlameHunk GgitBlameHunk;
 
 /**
- * GgitIndex:
+ * GgitFetchOptions:
  *
- * Represents an index object.
+ * Represents a git fetch options.
  */
-typedef struct _GgitIndex GgitIndex;
+typedef struct _GgitFetchOptions GgitFetchOptions;
 
 /**
  * GgitIndexEntries:
@@ -235,13 +151,6 @@ typedef struct _GgitIndexEntryResolveUndo GgitIndexEntryResolveUndo;
  */
 typedef struct _GgitMergeOptions GgitMergeOptions;
 
-/**
- * GgitNative:
- *
- * Represents a generic native object.
- */
-typedef struct _GgitNative GgitNative;
-
 /**
  * GgitNote:
  *
@@ -249,27 +158,6 @@ typedef struct _GgitNative GgitNative;
  */
 typedef struct _GgitNote GgitNote;
 
-/**
- * GgitObject:
- *
- * Represents a generic object in a repository.
- */
-typedef struct _GgitObject GgitObject;
-
-/**
- * GgitObjectFactory:
- *
- * Represents an object factory.
- */
-typedef struct _GgitObjectFactory GgitObjectFactory;
-
-/**
- * GgitObjectFactoryBase:
- *
- * Represents the base type for objects created by an object factory.
- */
-typedef struct _GgitObjectFactoryBase GgitObjectFactoryBase;
-
 /**
  * GgitOId:
  *
@@ -284,20 +172,6 @@ typedef struct _GgitOId GgitOId;
  */
 typedef struct _GgitPatch GgitPatch;
 
-/**
- * GgitPushOptions:
- *
- * Represents a git push options.
- */
-typedef struct _GgitPushOptions GgitPushOptions;
-
-/**
- * GgitRef:
- *
- * Reprensents a git reference.
- */
-typedef struct _GgitRef GgitRef;
-
 /**
  * GgitRefSpec:
  *
@@ -319,13 +193,6 @@ typedef struct _GgitReflog GgitReflog;
  */
 typedef struct _GgitReflogEntry GgitReflogEntry;
 
-/**
- * GgitRemote:
- *
- * Represents a git remote.
- */
-typedef struct _GgitRemote GgitRemote;
-
 /**
  * GgitRemoteHead:
  *
@@ -333,13 +200,6 @@ typedef struct _GgitRemote GgitRemote;
  */
 typedef struct _GgitRemoteHead GgitRemoteHead;
 
-/**
- * GgitRemoteCallbacks:
- *
- * Represents a git remote callbacks.
- */
-typedef struct _GgitRemoteCallbacks GgitRemoteCallbacks;
-
 /**
  * GgitRepository:
  *
@@ -348,20 +208,6 @@ typedef struct _GgitRemoteCallbacks GgitRemoteCallbacks;
  */
 typedef struct _GgitRepository GgitRepository;
 
-/**
- * GgitRevisionWalker:
- *
- * Represents a revision walker.
- */
-typedef struct _GgitRevisionWalker GgitRevisionWalker;
-
-/**
- * GgitSignature:
- *
- * Represents an action signature.
- */
-typedef struct _GgitSignature GgitSignature;
-
 /**
  * GgitStatusOptions:
  *
@@ -376,20 +222,6 @@ typedef struct _GgitStatusOptions GgitStatusOptions;
  */
 typedef struct _GgitSubmodule GgitSubmodule;
 
-/**
- * GgitSubmoduleUpdateOptions:
- *
- * Represents options for a submodule update.
- */
-typedef struct _GgitSubmoduleUpdateOptions GgitSubmoduleUpdateOptions;
-
-/**
- * GgitTag:
- *
- * Represents a tag object.
- */
-typedef struct _GgitTag GgitTag;
-
 /**
  * GgitTransferProgress:
  *
@@ -397,13 +229,6 @@ typedef struct _GgitTag GgitTag;
  */
 typedef struct _GgitTransferProgress GgitTransferProgress;
 
-/**
- * GgitTree:
- *
- * Represents a tree object.
- */
-typedef struct _GgitTree GgitTree;
-
 /**
  * GgitTreeEntry:
  *
@@ -411,13 +236,6 @@ typedef struct _GgitTree GgitTree;
  */
 typedef struct _GgitTreeEntry GgitTreeEntry;
 
-/**
- * GgitTreeBuilder:
- *
- * Represents a tree object.
- */
-typedef struct _GgitTreeBuilder GgitTreeBuilder;
-
 /**
  * GgitBlameOptions:
  *
@@ -425,20 +243,6 @@ typedef struct _GgitTreeBuilder GgitTreeBuilder;
  */
 typedef struct _GgitBlameOptions GgitBlameOptions;
 
-/**
- * GgitCheckoutOptions:
- *
- * Represents the options used when doign a checkout.
- */
-typedef struct _GgitCheckoutOptions GgitCheckoutOptions;
-
-/**
- * GgitCherryPickOptions:
- *
- * Represents the options used when doign a cherry-pick.
- */
-typedef struct _GgitCherryPickOptions GgitCherryPickOptions;
-
 /**
  * GgitRevertOptions:
  *
@@ -446,13 +250,6 @@ typedef struct _GgitCherryPickOptions GgitCherryPickOptions;
  */
 typedef struct _GgitRevertOptions GgitRevertOptions;
 
-/**
- * GgitFormatEmailOptions:
- *
- * Represents the options used when formatting a diff for e-mail.
- */
-typedef struct _GgitDiffFormatEmailOptions GgitDiffFormatEmailOptions;
-
 /**
  * GgitBranchType:
  * @GGIT_BRANCH_LOCAL: specifies a local branch.
@@ -473,6 +270,22 @@ typedef enum
 	GGIT_FEATURE_SSH     = (1 << 2)
 } GgitFeatureFlags;
 
+/**
+ * GgitDiffBinaryType:
+ * @GIT_DIFF_BINARY_NONE: There is no binary delta.
+ * @GIT_DIFF_BINARY_LITERAL: The binary data is the literal contents of the file.
+ * @GIT_DIFF_BINARY_DELTA: The binary data is the delta from one side to the other.
+ *
+ * When producing a binary diff, the binary data returned will be
+ * either the deflated full ("literal") contents of the file, or
+ * the deflated binary delta between the two sides (whichever is
+ * smaller).
+ */
+typedef enum {
+	GGIT_DIFF_BINARY_NONE,
+	GGIT_DIFF_BINARY_LITERAL,
+	GGIT_DIFF_BINARY_DELTA
+} GgitDiffBinaryType;
 
 /**
  * GgitBlameFlags:
@@ -736,14 +549,21 @@ typedef enum {
 /* NOTE: keep in sync with git2/refs.h */
 /**
  * GgitRemoteDownloadTagsType:
- * @GGIT_REMOTE_DOWNLOAD_TAGS_AUTO:
- * @GGIT_REMOTE_DOWNLOAD_TAGS_NONE:
- * @GGIT_REMOTE_DOWNLOAD_TAGS_ALL:
+ * @GGIT_REMOTE_DOWNLOAD_TAGS_UNSPECIFIED: Use the setting from the configuration.
+ * @GGIT_REMOTE_DOWNLOAD_TAGS_AUTO: Ask the server for tags pointing to objects we're already
+ * downloading.
+ * @GGIT_REMOTE_DOWNLOAD_TAGS_NONE: Don't ask for any tags beyond the refspecs.
+ * @GGIT_REMOTE_DOWNLOAD_TAGS_ALL: Ask for the all the tags.
+ *
+ * Automatic tag following option
+ *
+ * Lets us select the --tags option to use.
  */
 typedef enum {
-	GGIT_REMOTE_DOWNLOAD_TAGS_AUTO = 0,
-	GGIT_REMOTE_DOWNLOAD_TAGS_NONE = 1,
-	GGIT_REMOTE_DOWNLOAD_TAGS_ALL  = 2
+	GGIT_REMOTE_DOWNLOAD_TAGS_UNSPECIFIED = 0,
+	GGIT_REMOTE_DOWNLOAD_TAGS_AUTO,
+	GGIT_REMOTE_DOWNLOAD_TAGS_NONE,
+	GGIT_REMOTE_DOWNLOAD_TAGS_ALL
 } GgitRemoteDownloadTagsType;
 
 /* NOTE: keep in sync with git2/remote.h */
@@ -866,7 +686,7 @@ typedef enum {
 
 /**
  * GgitSubmoduleIgnore:
- * @GGIT_SUBMODULE_IGNORE_RESET: reset to on-disk value.
+ * @GGIT_SUBMODULE_IGNORE_UNSPECIFIED: reset to on-disk value.
  * @GGIT_SUBMODULE_IGNORE_NONE: don't ignore any change.
  * @GGIT_SUBMODULE_IGNORE_UNTRACKED: ignore untracked files.
  * @GGIT_SUBMODULE_IGNORE_DIRTY: ignore changes in the working directory.
@@ -875,14 +695,30 @@ typedef enum {
  * Describes which submodules should be ignored.
  */
 typedef enum {
-	GGIT_SUBMODULE_IGNORE_RESET     = -1,
+	GGIT_SUBMODULE_IGNORE_UNSPECIFIED = -1,
 
-	GGIT_SUBMODULE_IGNORE_NONE      = 1,
+	GGIT_SUBMODULE_IGNORE_NONE = 1,
 	GGIT_SUBMODULE_IGNORE_UNTRACKED = 2,
-	GGIT_SUBMODULE_IGNORE_DIRTY     = 3,
-	GGIT_SUBMODULE_IGNORE_ALL       = 4
+	GGIT_SUBMODULE_IGNORE_DIRTY = 3,
+	GGIT_SUBMODULE_IGNORE_ALL = 4
 } GgitSubmoduleIgnore;
 
+/**
+ * GgitSubmoduleRecurse:
+ * @GGIT_SUBMODULE_RECURSE_NO: do no recurse into submodules.
+ * @GGIT_SUBMODULE_RECURSE_YES: recurse into submodules.
+ * @GGIT_SUBMODULE_RECURSE_ONDEMAND: recurse into submodules only when
+ * commit not already in local clone.
+ *
+ * Options for submodule recurse.
+ * Represents the value of `submodule.$name.fetchRecurseSubmodules`
+ */
+typedef enum {
+	GGIT_SUBMODULE_RECURSE_NO = 0,
+	GGIT_SUBMODULE_RECURSE_YES = 1,
+	GGIT_SUBMODULE_RECURSE_ONDEMAND = 2
+} GgitSubmoduleRecurse;
+
 /**
  * GgitSubmoduleStatus:
  * FIXME
@@ -906,22 +742,24 @@ typedef enum {
 
 /**
  * GgitSubmoduleUpdate:
- * @GGIT_SUBMODULE_UPDATE_RESET: reset to on-disk value.
  * @GGIT_SUBMODULE_UPDATE_CHECKOUT: checkout the submodule.
  * @GGIT_SUBMODULE_UPDATE_REBASE: rebase the current branch onto the
  *                                commit recorded in the superproject.
  * @GGIT_SUBMODULE_UPDATE_MERGE: merge the commit recorded in the
  *                               superproject into the current branch.
  * @GGIT_SUBMODULE_UPDATE_NONE: do not update this submodule.
+ * @GGIT_SUBMODULE_UPDATE_DEFAULT: not used except as static initializer
+ * when we don't want any particular update rule to be specified.
  *
  * Describes how a submodule should be updated.
  */
 typedef enum {
-	GGIT_SUBMODULE_UPDATE_RESET    = -1,
 	GGIT_SUBMODULE_UPDATE_CHECKOUT = 1,
 	GGIT_SUBMODULE_UPDATE_REBASE   = 2,
 	GGIT_SUBMODULE_UPDATE_MERGE    = 3,
-	GGIT_SUBMODULE_UPDATE_NONE     = 4
+	GGIT_SUBMODULE_UPDATE_NONE     = 4,
+
+	GGIT_SUBMODULE_UPDATE_DEFAULT = 0
 } GgitSubmoduleUpdate;
 
 /**
@@ -1027,8 +865,8 @@ typedef enum
 {
 	GGIT_CHECKOUT_NONE                    = 0,
 	GGIT_CHECKOUT_SAFE                    = (1u << 0),
-	GGIT_CHECKOUT_SAFE_CREATE             = (1u << 1),
-	GGIT_CHECKOUT_FORCE                   = (1u << 2),
+	GGIT_CHECKOUT_FORCE                   = (1u << 1),
+	GGIT_CHECKOUT_RECREATE_MISSING        = (1u << 2),
 	GGIT_CHECKOUT_ALLOW_CONFLICTS         = (1u << 4),
 	GGIT_CHECKOUT_REMOVE_UNTRACKED        = (1u << 5),
 	GGIT_CHECKOUT_REMOVE_IGNORED          = (1u << 6),
@@ -1042,7 +880,11 @@ typedef enum
 	GGIT_CHECKOUT_SKIP_LOCKED_DIRECTORIES = (1u << 18),
 	GGIT_CHECKOUT_DONT_OVERWRITE_IGNORED  = (1u << 19),
 	GGIT_CHECKOUT_CONFLICT_STYLE_MERGE    = (1u << 20),
-	GGIT_CHECKOUT_CONFLICT_STYLE_DIFF3    = (1u << 21)
+	GGIT_CHECKOUT_CONFLICT_STYLE_DIFF3    = (1u << 21),
+	GGIT_CHECKOUT_DONT_REMOVE_EXISTING    = (1u << 22),
+	GGIT_CHECKOUT_DONT_WRITE_INDEX        = (1u << 23),
+	GGIT_CHECKOUT_UPDATE_SUBMODULES       = (1u << 16),
+	GGIT_CHECKOUT_UPDATE_SUBMODULES_IF_CHANGED = (1u << 17)
 } GgitCheckoutStrategy;
 
 typedef enum {
@@ -1128,21 +970,18 @@ typedef gint (* GgitConfigMatchCallback) (GMatchInfo  *match_info,
                                           gpointer     user_data);
 
 /**
- * GgitCredAcquireCallback:
- * @url: the resource for which we are demanding a credential.
- * @username_from_url: (allow-none): The username that was embedded in a "user@host"
- *                                   remote url, or NULL if not included.
- * @allowed_types: a bitmask stating which cred types are OK to return.
- * @cred: (transfer full): newly created credential object.
+ * GgitDiffBinaryCallback:
+ * @delta: a #GgitDiffDelta.
+ * @binary: a #GgitDiffBinary.
  * @user_data: (closure): user-supplied data.
  *
- * Signature of a function which acquires a credential object.
+ * Called for each file.
+ *
+ * Returns: 0 to go continue or a #GgitError in case there was an error.
  */
-typedef gint (* GgitCredAcquireCallback) (const gchar *url,
-                                          const gchar *username_from_url,
-                                          guint        allowed_types,
-                                          GgitCred   **cred,
-                                          gpointer     user_data);
+typedef gint (* GgitDiffBinaryCallback) (GgitDiffDelta  *delta,
+                                         GgitDiffBinary *binary,
+                                         gpointer        user_data);
 
 /**
  * GgitDiffFileCallback:
